<h1 align="center">Wuddz String/Mac Address Permutations/Combinations Generator</h1>

## Description
 - A Simple Script That Generates All/Non-Repeat Character Permutations/Combinations Of String Or Mac Addresses With Prefix/Suffix Partial Address
 - Of Note Uses Lazy Generators, Will Take Some Time To Generate Huge Lists But Won't Be Memory Intensive
 - Honestly Wrote This Quick Script As I Needed Some Of It's Implementation, Thought I'd Share.

## Prerequisites
 - Python : 3.7

## Installation
Install using [PyPI](https://pypi.org/project/wuddz-perms):
```
$ pip install wuddz-perms
```
Install locally by cloning or downloading and extracting the repo, then cd into 'dist' directory and execute:
```
$ pip install wuddz_perms-1.0.1.tar.gz
```
Then to run it, execute the following in the terminal:
```
$ wudz-perms
```

### Usage
Generate All Lower, Upper & Punctuation 4 Character Length Combinations To Default "output.txt" File.
```
$ wudz-perms -all -l 4
```
Generate All Combinations Of String To Default "output.txt" File.
```
$ wudz-perms -all -a wuddzdevs
```
Generate All Lower & Upper Case Permutations Of String To Default "output.txt" File.
```
$ wudz-perms -upl -a pythondev
```
Generate All Non Repeat Character Permutations Of String To Default "output.txt" File.
```
$ wudz-perms -nrc -a talented
```
Generate Mac Addresses With Specified Prefix/Suffix To Default "output.txt" File.
```
$ wudz-perms -mac -p 00:1a:65:ff
```

## Contact Info:
 - Email:     wuddz_devs@protonmail.com                                                              
 - Github:    https://github.com/wuddz-devs                                                          
 - Telegram:  https://t.me/wuddz_devs
 - Youtube:   https://youtube.com/@wuddz-devs
 - Reddit:    https://reddit.com/user/wuddz-devs

### Buy Me A Coffee!!
 - ERC20 Address: 0x1F1C47dD653Af628D394eac7bAA9Ccf774fd784f

#### Peace & Love Always!!
